@@ -1,6 +1,4 @@
 /*
-   +----------------------------------------------------------------------+
-   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
    | Copyright (c) The PHP Group                                          |
    +----------------------------------------------------------------------+
@@ -19,12 +17,15 @@
 #include "php.h"
 #include "basic_functions.h"
 #include "crc32.h"
+#include "crc32_x86.h"
 
 #if HAVE_AARCH64_CRC32
 # include <arm_acle.h>
 # if defined(__linux__)
 #  include <sys/auxv.h>
 #  include <asm/hwcap.h>
+# elif defined(__APPLE__)
+#  include <sys/sysctl.h>
 # endif
 
 static inline int has_crc32_insn() {
@@ -38,6 +39,11 @@ static inline int has_crc32_insn() {
 # elif defined(HWCAP2_CRC32)
 	res = getauxval(AT_HWCAP2) & HWCAP2_CRC32;
 	return res;
+# elif defined(__APPLE__)
+	size_t reslen = sizeof(res);
+	if (sysctlbyname("hw.optional.armv8_crc32", &res, &reslen, NULL, 0) < 0)
+		res = 0;
+	return res;
 # else
 	res = 0;
 	return res;
@@ -70,14 +76,13 @@ static uint32_t crc32_aarch64(uint32_t crc, char *p, size_t nr) {
 # pragma GCC pop_options
 #endif
 
-/* {{{ proto string crc32(string str)
-   Calculate the crc32 polynomial of a string */
-PHP_NAMED_FUNCTION(php_if_crc32)
+/* {{{ Calculate the crc32 polynomial of a string */
+PHP_FUNCTION(crc32)
 {
 	char *p;
 	size_t nr;
 	uint32_t crcinit = 0;
-	register uint32_t crc;
+	uint32_t crc;
 
 	ZEND_PARSE_PARAMETERS_START(1, 1)
 		Z_PARAM_STRING(p, nr)
@@ -92,6 +97,12 @@ PHP_NAMED_FUNCTION(php_if_crc32)
 	}
 #endif
 
+#if ZEND_INTRIN_SSE4_2_PCLMUL_NATIVE || ZEND_INTRIN_SSE4_2_PCLMUL_RESOLVER
+	size_t nr_simd = crc32_x86_simd_update(X86_CRC32B, &crc, (const unsigned char *)p, nr);
+	nr -= nr_simd;
+	p += nr_simd;
+#endif
+
 	for (; nr--; ++p) {
 		crc = ((crc >> 8) & 0x00FFFFFF) ^ crc32tab[(crc ^ (*p)) & 0xFF ];
 	}
